@@ -55,7 +55,7 @@ def setup_logging(sample_name: str, log_filename: Optional[str] = None) -> None:
     
     logging.basicConfig(
         level=logging.INFO,
-        format="%(asctime)s [%(levelname)s] %(message)s",
+        format="[%(levelname)s] %(message)s",
         handlers=[
             logging.FileHandler(log_filename, mode="a", encoding="utf-8")
         ],
